import { ChangeDetectorRef, Component, OnInit, ViewChild } from '@angular/core';
import { MatDialog } from '@angular/material/dialog';
import { MatPaginator } from '@angular/material/paginator';
import { MatSort } from '@angular/material/sort';
import { MatTableDataSource } from '@angular/material/table';
import { NavioService } from '../../../services/navio.service';
import { CoreService } from '../../../core/core.service';
import { CommonModule } from '@angular/common';
import { FormsModule, ReactiveFormsModule } from '@angular/forms';
import { MatButtonModule } from '@angular/material/button';
import { MatInputModule } from '@angular/material/input';
import { MatFormFieldModule } from '@angular/material/form-field';
import { MatDatepickerModule } from '@angular/material/datepicker';
import { MatSelectModule } from '@angular/material/select';
import { MatRadioModule } from '@angular/material/radio';
import { MatIconModule } from '@angular/material/icon';
import { MatSnackBarModule } from '@angular/material/snack-bar';
import { MatTableModule } from '@angular/material/table';
import { MatToolbarModule } from '@angular/material/toolbar';
import { MatPaginatorModule } from '@angular/material/paginator';
import { MatSortModule } from '@angular/material/sort';
import { PageEvent } from '@angular/material/paginator';
import { AddSearchComponent } from '../../../shared/addAndSearch/add-search/add-search.component';
import { JwtDecoderService } from '../../../jwt-decoder.service';
import { AuthService } from '../../../auth.service';
import { jwtDecode } from 'jwt-decode';
import { BlackListAddComponent } from '../../crud-blackList/black-list-add/black-list-add.component';
import { BlackListEdit } from '../black-list-edit/black-list-edit.component';
import { BlackListService } from '../../../services/Blacklists/black-list.service';
import { VisualizacaoBlackListComponent } from '../visualizacao-black-list/visualizacao-black-list.component';

interface NavioData {
  id: number;
  imo: number;
  mmsi: number;
  nome: string;
  loa: number;
  boca: number;
  dwt: number;
  pontal: number;
  ponte_mfold: number;
  mfold_quilha: number;
  categoria: number;
  flag: string;
  obs: string;
  action: number;
}
@Component({
  selector: 'app-black-list',
  standalone: true,
  imports: [
    MatPaginatorModule,
    MatToolbarModule,
    MatTableModule,
    CommonModule,
    FormsModule,
    ReactiveFormsModule,
    MatButtonModule,
    MatInputModule,
    MatFormFieldModule,
    MatDatepickerModule,
    MatSelectModule,
    MatRadioModule,
    MatIconModule,
    MatSnackBarModule,
    MatSortModule,
    AddSearchComponent,
  ],
  templateUrl: './black-list.component.html',
  styleUrl: './black-list.component.scss',
})
export class BlackListComponent {
  user: any;
  authTokenPresent = false;
  totalItems = 100;
  pageSize = 10;
  currentPage = 1;

  displayedColumns: string[] = [
    'id',
    'imo',
    'mmsi',
    'nome',
    'categoria',
    'flag',
    'action',
  ];

  dataSource = new MatTableDataSource<NavioData>();

  @ViewChild(MatPaginator) paginator!: MatPaginator;
  @ViewChild(MatSort) sort!: MatSort;

  constructor(
    private _dialog: MatDialog,
    private _navioService: BlackListService,
    private jwtDecoderService: JwtDecoderService,
    private authService: AuthService,
    private _coreService: CoreService,
    private cdr: ChangeDetectorRef,
    
  ) {}
  ngOnInit(): void {
    this.validationToken();
  }

  ngAfterViewInit(): void {
    this.loadData();
  }

  validationToken() {
    this.authService.authToken$.subscribe((isLoggedIn) => {
      this.authTokenPresent = isLoggedIn;
      if (this.authTokenPresent) {
        const token = sessionStorage.getItem('accessToken')!;
        this.user = jwtDecode(token);
        const isExpired =
          this.user && this.user.exp
            ? this.user.exp < Date.now() / 1000
            : false;
        if (isExpired) {
          sessionStorage.removeItem('accessToken');
        }
        this.user = this.jwtDecoderService.decodeToken(token);
        console.log(this.user);
      }
      this.cdr.detectChanges();
    });
  }

  loadData(event?: PageEvent) {
    const pageIndex = event ? event.pageIndex + 1 : this.currentPage - 1;

    this._navioService.getEmployeeList(pageIndex, this.pageSize).subscribe({
      next: (res: any) => {
        const navios = res._embedded.blackListResponseList;
        console.log(navios);
        this.dataSource.data = navios;
        this.totalItems = res.page.totalElements;
        console.log(res.page.totalElements);
      },
      error: (err: any) => {
        console.error(err);
        if (err.error.title) {
          this._coreService.openSnackBar(err.error.title);
        } else {
          this._coreService.openSnackBar(err.error.message);
        }
      },
    });
  }

  applyFilter(event: Event) {
    const filterValue = (event.target as HTMLInputElement).value;
    this.dataSource.filter = filterValue.trim().toLowerCase();

    if (this.dataSource.paginator) {
      this.dataSource.paginator.firstPage();
    }
  }

  deleteEmployee(id: number) {
    this._navioService.deleteEmployee(id).subscribe({
      next: () => {
        this._coreService.openSnackBar('Navio deleted!', 'done');
        this.loadData();
      },
      error: (err: any) => {
        this._coreService.openSnackBar(err.error.title);
      },
    });
  }

  openEditForm(data: any) {
    this._dialog.open(BlackListEdit, {
      data,
      autoFocus: true, // Foca no primeiro campo interativo do formulário
      disableClose: true, // Impede que o diálogo feche ao clicar fora
      width: '600px', // Define a largura do diálogo
    });
    this.cdr.detectChanges();

  }

  addBlackList(data:any){
    this._dialog.open(BlackListAddComponent, {
      data,
      autoFocus: true, // Foca no primeiro campo interativo do formulário
      disableClose: true, // Impede que o diálogo feche ao clicar fora
      width: '600px', // Define a largura do diálogo
    });
    this.cdr.detectChanges();

  }

  openAddEmpForm() {
    this._dialog.open(BlackListAddComponent,{autoFocus: true, // Foca no primeiro campo interativo do formulário
      disableClose: true, // Impede que o diálogo feche ao clicar fora
      width: '600px', // Define a largura do diálogo}));
  })
  this.cdr.detectChanges();
}


  getAceiteById(data: any) {
    this._dialog.open(VisualizacaoBlackListComponent, {
      data,
      autoFocus: true, // Foca no primeiro campo interativo do formulário
      width: '800px', // Define a largura do diálogo
    });
    this.cdr.detectChanges();

  }
}
